cross_device_integrity library

Classes

DeviceIntegrityChecker
Main entry point for performing device integrity and security checks.
DeviceIntegrityConfig
Configuration options to customize device integrity checks.
IntegrityResult
Aggregated result of device integrity checks with detailed diagnostic info.

Enums

IntegrityCheckType
Types of security checks supported by Device Integrity.
IntegrityStatus
Status of a specific integrity check.