IntegrityStatus enum

Status of a specific integrity check.

Inheritance
Available extensions

Values

secure → const IntegrityStatus

The check passed — the device environment is secure for this signal.

compromised → const IntegrityStatus

The check failed — a security threat or modification was detected.

unsupported → const IntegrityStatus

The check is not supported or not applicable on this platform.

error → const IntegrityStatus

An error occurred while executing the check.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isCompromised bool

Available on IntegrityStatus, provided by the IntegrityStatusX extension

no setter
isError bool

Available on IntegrityStatus, provided by the IntegrityStatusX extension

no setter
isSecure bool

Available on IntegrityStatus, provided by the IntegrityStatusX extension

no setter
isUnsupported bool

Available on IntegrityStatus, provided by the IntegrityStatusX extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nameString String

Available on IntegrityStatus, provided by the IntegrityStatusX extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IntegrityStatus>
A constant List of the values in this enum, in order of their declaration.